==> db-0.3.1.jar: burningswell/db/weather/variables.clj <==
(ns burningswell.db.weather.variables
  (:require [datumbazo.table :as t]))

(t/deftable variables
  "The weather variables table."
  (t/table :weather.variables)
  (t/column :created-at :timestamp :not-null? true)
  (t/column :description :text)
  (t/column :id :integer :primary-key? true)
  (t/column :name :citext :unique? true)
  (t/column :unit :text)
  (t/column :updated-at :timestamp :not-null? true))

(defn htsgwsfc
  "Return the significant height of combined wind waves and swell
  variable."
  [db]
  (by-name db "htsgwsfc"))

;; (defn- select-all [db & [opts]]
;;   (select db [:weather.variables.id
;;               :weather.variables.name
;;               :weather.variables.description
;;               :weather.variables.unit
;;               :weather.variables.created-at
;;               :weather.variables.updated-at]
;;     (from :weather.variables)
;;     (paginate (:page opts) (:per-page opts))
;;     (order-by :weather.variables.name)))

;; (s/defn all :- [WeatherVariable]
;;   "Return all weather variables in `db`."
;;   [db :- Database]
;;   @(select-all db))

;; (s/defn by-id :- (s/maybe WeatherVariable)
;;   "Return the weather variable in `db` by `id`."
;;   [db :- Database id :- s/Int]
;;   (first @(compose
;;            (select-all db)
;;            (where `(= :weather.variables.id (cast ~id :integer))))))

;; (s/defn by-name :- (s/maybe WeatherVariable)
;;   "Return the weather variable in `db` by `name`."
;;   [db :- Database name :- s/Str]
;;   (first @(compose
;;            (select-all db)
;;            (where `(= :weather.variables.name ~name)))))

;; (s/defn by-names :- [WeatherVariable]
;;   "Return the weather variables in `db` with a name in `names`."
;;   [db :- Database names :- [s/Str]]
;;   @(compose
;;     (select-all db)
;;     (where `(in :weather.variables.name ~(seq names)))))

;; (s/defn by-names-or-all :- [WeatherVariable]
;;   "Return the weather variables in `db` with a name in `names`, or all
;;   weather variables if `names` is empty."
;;   [db :- Database names :- [s/Str]]
;;   (if (empty? names)
;;     (all db) (by-names db names)))

==> db-0.3.2.jar: burningswell/db/weather/variables.clj <==
(ns burningswell.db.weather.variables
  (:require [clojure.spec.alpha :as s]
            [clojure.string :as str]
            [datumbazo.table :as t]
            [datumbazo.core :as sql]))

(t/deftable variables
  "The weather variables table."
  (t/table :weather.variables)
  (t/column :created-at :timestamp :not-null? true)
  (t/column :description :text)
  (t/column :id :integer :primary-key? true)
  (t/column :name :citext :unique? true)
  (t/column :unit :text)
  (t/column :updated-at :timestamp :not-null? true))

(defn htsgwsfc
  "Return the significant height of combined wind waves and swell
  variable."
  [db]
  (by-name db "htsgwsfc"))

(s/fdef htsgwsfc
  :args (s/cat :db sql/db?))

(defn by-model
  "Returns the variables of `model`."
  [db model]
  @(sql/select db [:variables.*]
     (sql/from :weather.variables)
     (sql/join :weather.models-variables.variable-id
               :weather.variables.id)
     (sql/where `(= :models-variables.model-id ~(:id model)))
     (sql/order-by :variables.name)))

(s/fdef by-model
  :args (s/cat :db sql/db? :model :burningswell.db.weather.models/model))

(defn by-datasource
  "Returns the variables of the `datasource` model."
  [db datasource]
  {:id (:model-id datasource)}
  (by-model db {:id (:model-id datasource)}))

(s/fdef by-datasource
  :args (s/cat :db sql/db? :model :burningswell.db.weather.datasources/datasource))

(defn by-names
  "Returns the variables for the given `names`."
  [db names]
  (->> @(sql/select db [:*]
          (sql/from :weather.variables)
          (sql/where `(in :name ~(remove str/blank? names)))
          (sql/order-by :name))
       (not-empty)))

(s/fdef by-names
  :args (s/cat :db sql/db? :names (s/coll-of string?))
  :ret (s/nilable (s/coll-of ::model)))

;; (defn- select-all [db & [opts]]
;;   (select db [:weather.variables.id
;;               :weather.variables.name
;;               :weather.variables.description
;;               :weather.variables.unit
;;               :weather.variables.created-at
;;               :weather.variables.updated-at]
;;     (from :weather.variables)
;;     (paginate (:page opts) (:per-page opts))
;;     (order-by :weather.variables.name)))

;; (s/defn all :- [WeatherVariable]
;;   "Return all weather variables in `db`."
;;   [db :- Database]
;;   @(select-all db))

;; (s/defn by-id :- (s/maybe WeatherVariable)
;;   "Return the weather variable in `db` by `id`."
;;   [db :- Database id :- s/Int]
;;   (first @(compose
;;            (select-all db)
;;            (where `(= :weather.variables.id (cast ~id :integer))))))

;; (s/defn by-name :- (s/maybe WeatherVariable)
;;   "Return the weather variable in `db` by `name`."
;;   [db :- Database name :- s/Str]
;;   (first @(compose
;;            (select-all db)
;;            (where `(= :weather.variables.name ~name)))))

;; (s/defn by-names :- [WeatherVariable]
;;   "Return the weather variables in `db` with a name in `names`."
;;   [db :- Database names :- [s/Str]]
;;   @(compose
;;     (select-all db)
;;     (where `(in :weather.variables.name ~(seq names)))))

;; (s/defn by-names-or-all :- [WeatherVariable]
;;   "Return the weather variables in `db` with a name in `names`, or all
;;   weather variables if `names` is empty."
;;   [db :- Database names :- [s/Str]]
;;   (if (empty? names)
;;     (all db) (by-names db names)))
